@@ -40,6 +40,20 @@ class Browser(webdriver.Chrome):
     hide (True default): esconde a janela
     clean (True default): limpa o cache da janela
     """
+    
+    @classmethod
+    def unhide(self):
+        self.set_window_position(0, 0)
+
+    @classmethod
+    def hide(self):
+        self.set_window_position(10000, 10000)
+
+    @classmethod
+    def get_focus(self):
+        __currentWindow = self.getWindowHandle()
+        self.switchTo().window(currentWindow)
+
 
     @classmethod
     def __expand_shadow_element(self, __browser, element):
@@ -47,20 +61,7 @@ class Browser(webdriver.Chrome):
         return __shadow_root
 
 
-    # setting up the browser
-    __caps = DesiredCapabilities().CHROME
-    __caps["pageLoadStrategy"] = "eager"
-    # noinspection SpellCheckingInspection
-    __options = webdriver.ChromeOptions()
-    __chrome_preferences = {'profile.managed_default_content_settings.images': 2}
-    # noinspection SpellCheckingInspection
-    __options.add_experimental_option("prefs", __chrome_preferences)
-    __options.add_argument("disable-infobars")
 
-    session_id = ''
-    command_executor = ''
-    error_handler = ''
-    w3c=False
 
     def __init__(self, hide=True, clean=True, **kwargs):
 
@@ -76,6 +77,10 @@ class Browser(webdriver.Chrome):
 
         if self.__hide and not self.__clean:
             self.__options.add_argument("headless")
+        try:
+            __pictures = kwargs['pictures']
+        except:
+            __pictures = False
         try:
             kill_chromedrivers = kwargs['kill']
         except:
@@ -88,7 +93,21 @@ class Browser(webdriver.Chrome):
                         os.system("taskkill /f /im  chromedriver.exe")
                     except:
                         pass
+            # setting up the browser
+        __caps = DesiredCapabilities().CHROME
+        __caps["pageLoadStrategy"] = "eager"
+        # noinspection SpellCheckingInspection
+        __options = webdriver.ChromeOptions()
+        if not __pictures:
+            __chrome_preferences = {'profile.managed_default_content_settings.images': 2}
+            # noinspection SpellCheckingInspection
+            __options.add_experimental_option("prefs", __chrome_preferences)
+        __options.add_argument("disable-infobars")
 
+        session_id = ''
+        command_executor = ''
+        error_handler = ''
+        w3c = False
         # noinspection SpellCheckingInspection
         Browser = webdriver.Chrome(options=self.__options, service_args=['--silent'], desired_capabilities=self.__caps)
         Browser.header_overrides = Header
